@@ -3,7 +3,7 @@ package CPAN::Testers::WWW::Reports::Query::Report;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
  
 #----------------------------------------------------------------------------
 
@@ -104,6 +104,10 @@ sub report {
     }
 
     $self->{content} = $mech->content;
+    unless($self->{content}) {
+        $self->{error} = 'no data returned by the server';
+        return;
+    }
 
     my $data;
     eval {
@@ -150,6 +154,11 @@ sub _parse {
     return $data;
 }
 
+sub content {
+    my $self    = shift;
+    return $self->{content};
+}
+
 sub error {
     my $self    = shift;
     return $self->{error};
@@ -187,6 +196,10 @@ report.
 
 =over 4
 
+=item * content
+
+Returns the current server textual response. Useful for debugging.
+
 =item * error
 
 Returns the last recorded error.
@@ -247,7 +260,7 @@ L<http://iheart.cpantesters.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (C) 2014 Barbie for Miss Barbell Productions.
+  Copyright (C) 2014-2016 Barbie for Miss Barbell Productions.
 
   This module is free software; you can redistribute it and/or
   modify it under the Artistic License 2.0.
